@@ -12,7 +12,6 @@
 #include "config/mode.h"
 #include "config/output_format.h"
 #include "config/string_array.h"
-#include "config/types.h"
 
 /* Init/destroy */
 int handle_flags_config(int , char **);
@@ -45,6 +44,7 @@ bool config_get_rsync_enabled(void);
 unsigned int config_get_rsync_priority(void);
 unsigned int config_get_rsync_retry_count(void);
 unsigned int config_get_rsync_retry_interval(void);
+long config_get_rsync_transfer_timeout(void);
 char *config_get_rsync_program(void);
 struct string_array const *config_get_rsync_args(void);
 bool config_get_http_enabled(void);
