@@ -2,11 +2,9 @@
 
 #include <curl/curl.h>
 
-#include "alloc.h"
 #include "cache/local_cache.h"
 #include "common.h"
 #include "config.h"
-#include "data_structure/uthash.h"
 #include "file.h"
 #include "log.h"
 
@@ -153,6 +151,8 @@ http_easy_init(struct http_handler *handler, curl_off_t ims)
 
 	setopt_str(result, CURLOPT_USERAGENT, config_get_http_user_agent());
 
+	setopt_str(result, CURLOPT_ACCEPT_ENCODING, "");
+
 	setopt_long(result, CURLOPT_FOLLOWLOCATION, 1);
 	setopt_long(result, CURLOPT_MAXREDIRS, config_get_max_redirs());
 
